==> zzyj-outputvalcount-impl-3.0.0-20250109.063954-328-sources.jar: com/ejianc/business/outputvalcount/bean/MonthlyStatisticsPayDetailEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 月度产值与统计-付款详情
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_monthly_statistics_pay_detail")
public class MonthlyStatisticsPayDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="zhu_id")
    private Long zhuId; // 主表id
    @TableField(value="pay_remark_id")
    private Long payRemarkId; // 付款节点
    @TableField(value="pay_node")
    private String payNode; // 付款节点说明
    @TableField(value="pay_node_num")
    private Integer payNodeNum; // 节点批次
    @TableField(value="pay_per")
    private String payPer; // 支付百分比
    @TableField(value="mny_pay_per")
    private BigDecimal mnyPayPer; // 支付百分比数值
    @TableField(value="total_quote_mny")
    private BigDecimal totalQuoteMny; // 累计对甲报量
    @TableField(value="last_quote_mny")
    private BigDecimal lastQuoteMny; // 上月累计对甲报量
    @TableField(value="quote_mny")
    private BigDecimal quoteMny; // 对甲报量
    @TableField(value="receive_mny")
    private BigDecimal receiveMny; // 应收金额
    @TableField(value="last_receive_mny")
    private BigDecimal lastReceiveMny; // 上月累计应收金额
    @TableField(value="total_receive_mny")
    private BigDecimal totalReceiveMny; // 累计应收
    @TableField(value="change_quote_mny")
    private BigDecimal changeQuoteMny; // 已报送偏差
    @TableField(value="service_date")
    private Date serviceDate; // 业务日期
    @TableField(value="detail_type")
    private String detailType; // 类型
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getZhuId() {
        return zhuId;
    }

    public void setZhuId(Long zhuId) {
        this.zhuId = zhuId;
    }
    public Long getPayRemarkId() {
        return payRemarkId;
    }

    public void setPayRemarkId(Long payRemarkId) {
        this.payRemarkId = payRemarkId;
    }
    public String getPayNode() {
        return payNode;
    }

    public void setPayNode(String payNode) {
        this.payNode = payNode;
    }
    public Integer getPayNodeNum() {
        return payNodeNum;
    }

    public void setPayNodeNum(Integer payNodeNum) {
        this.payNodeNum = payNodeNum;
    }
    public String getPayPer() {
        return payPer;
    }

    public void setPayPer(String payPer) {
        this.payPer = payPer;
    }
    public BigDecimal getMnyPayPer() {
        return mnyPayPer;
    }

    public void setMnyPayPer(BigDecimal mnyPayPer) {
        this.mnyPayPer = mnyPayPer;
    }
    public BigDecimal getTotalQuoteMny() {
        return totalQuoteMny;
    }

    public void setTotalQuoteMny(BigDecimal totalQuoteMny) {
        this.totalQuoteMny = totalQuoteMny;
    }
    public BigDecimal getLastQuoteMny() {
        return lastQuoteMny;
    }

    public void setLastQuoteMny(BigDecimal lastQuoteMny) {
        this.lastQuoteMny = lastQuoteMny;
    }
    public BigDecimal getQuoteMny() {
        return quoteMny;
    }

    public void setQuoteMny(BigDecimal quoteMny) {
        this.quoteMny = quoteMny;
    }
    public BigDecimal getReceiveMny() {
        return receiveMny;
    }

    public void setReceiveMny(BigDecimal receiveMny) {
        this.receiveMny = receiveMny;
    }
    public BigDecimal getLastReceiveMny() {
        return lastReceiveMny;
    }

    public void setLastReceiveMny(BigDecimal lastReceiveMny) {
        this.lastReceiveMny = lastReceiveMny;
    }
    public BigDecimal getTotalReceiveMny() {
        return totalReceiveMny;
    }

    public void setTotalReceiveMny(BigDecimal totalReceiveMny) {
        this.totalReceiveMny = totalReceiveMny;
    }
    public BigDecimal getChangeQuoteMny() {
        return changeQuoteMny;
    }

    public void setChangeQuoteMny(BigDecimal changeQuoteMny) {
        this.changeQuoteMny = changeQuoteMny;
    }

    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }

    public String getDetailType() {
        return detailType;
    }

    public void setDetailType(String detailType) {
        this.detailType = detailType;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}

==> zzyj-outputvalcount-impl-3.0.0-20250115.033745-330-sources.jar: com/ejianc/business/outputvalcount/bean/MonthlyStatisticsPayDetailEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 月度产值与统计-付款详情
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_monthly_statistics_pay_detail")
public class MonthlyStatisticsPayDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="zhu_id")
    private Long zhuId; // 主表id
    @TableField(value="pay_remark_id")
    private Long payRemarkId; // 付款节点
    @TableField(value="pay_node")
    private String payNode; // 付款节点说明
    @TableField(value="pay_node_num")
    private Integer payNodeNum; // 节点批次
    @TableField(value="pay_per")
    private String payPer; // 支付百分比
    @TableField(value="mny_pay_per")
    private BigDecimal mnyPayPer; // 支付百分比数值
    @TableField(value="total_quote_mny")
    private BigDecimal totalQuoteMny; // 累计对甲报量
    @TableField(value="last_quote_mny")
    private BigDecimal lastQuoteMny; // 上月累计对甲报量
    @TableField(value="quote_mny")
    private BigDecimal quoteMny; // 对甲报量
    @TableField(value="receive_mny")
    private BigDecimal receiveMny; // 应收金额
    @TableField(value="last_receive_mny")
    private BigDecimal lastReceiveMny; // 上月累计应收金额
    @TableField(value="total_receive_mny")
    private BigDecimal totalReceiveMny; // 累计应收
    @TableField(value="change_quote_mny")
    private BigDecimal changeQuoteMny; // 已报送偏差
    @TableField(value="service_date")
    private Date serviceDate; // 业务日期
    @TableField(value="detail_type")
    private String detailType; // 类型
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="last_id")
    private Long lastId; // 初始版本id


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getZhuId() {
        return zhuId;
    }

    public void setZhuId(Long zhuId) {
        this.zhuId = zhuId;
    }
    public Long getPayRemarkId() {
        return payRemarkId;
    }

    public void setPayRemarkId(Long payRemarkId) {
        this.payRemarkId = payRemarkId;
    }
    public String getPayNode() {
        return payNode;
    }

    public void setPayNode(String payNode) {
        this.payNode = payNode;
    }
    public Integer getPayNodeNum() {
        return payNodeNum;
    }

    public void setPayNodeNum(Integer payNodeNum) {
        this.payNodeNum = payNodeNum;
    }
    public String getPayPer() {
        return payPer;
    }

    public void setPayPer(String payPer) {
        this.payPer = payPer;
    }
    public BigDecimal getMnyPayPer() {
        return mnyPayPer;
    }

    public void setMnyPayPer(BigDecimal mnyPayPer) {
        this.mnyPayPer = mnyPayPer;
    }
    public BigDecimal getTotalQuoteMny() {
        return totalQuoteMny;
    }

    public void setTotalQuoteMny(BigDecimal totalQuoteMny) {
        this.totalQuoteMny = totalQuoteMny;
    }
    public BigDecimal getLastQuoteMny() {
        return lastQuoteMny;
    }

    public void setLastQuoteMny(BigDecimal lastQuoteMny) {
        this.lastQuoteMny = lastQuoteMny;
    }
    public BigDecimal getQuoteMny() {
        return quoteMny;
    }

    public void setQuoteMny(BigDecimal quoteMny) {
        this.quoteMny = quoteMny;
    }
    public BigDecimal getReceiveMny() {
        return receiveMny;
    }

    public void setReceiveMny(BigDecimal receiveMny) {
        this.receiveMny = receiveMny;
    }
    public BigDecimal getLastReceiveMny() {
        return lastReceiveMny;
    }

    public void setLastReceiveMny(BigDecimal lastReceiveMny) {
        this.lastReceiveMny = lastReceiveMny;
    }
    public BigDecimal getTotalReceiveMny() {
        return totalReceiveMny;
    }

    public void setTotalReceiveMny(BigDecimal totalReceiveMny) {
        this.totalReceiveMny = totalReceiveMny;
    }
    public BigDecimal getChangeQuoteMny() {
        return changeQuoteMny;
    }

    public void setChangeQuoteMny(BigDecimal changeQuoteMny) {
        this.changeQuoteMny = changeQuoteMny;
    }

    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }

    public String getDetailType() {
        return detailType;
    }

    public void setDetailType(String detailType) {
        this.detailType = detailType;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getLastId() {
        return lastId;
    }

    public void setLastId(Long lastId) {
        this.lastId = lastId;
    }
}
